export interface Attendee {
    /**
     * The attendee's Profile ID, if available. It corresponds to the id field in the People collection of the Google+ API
     */
    id?: string;
    /**
     * The attendee's email address, if available. This field must be present when adding an attendee. It must be a valid email address as per RFC5322.
     * Required when adding an attendee.
     */
    email?: string;
    /**
     * The attendee's name, if available. Optional.
     */
    displayName?: string;
    /**
     * Whether the attendee is the organizer of the event. Read-only. The default is False.
     */
    organizer?: boolean;
    /**
     * Whether this entry represents the calendar on which this copy of the event appears. Read-only. The default is False.
     */
    self?: boolean;
    /**
     * Whether the attendee is a resource. Can only be set when the attendee is added to the event for the first time. Subsequent modifications are ignored. Optional. The default is False.
     */
    resource?: boolean;
    /**
     * Whether this is an optional attendee. Optional. The default is False.
     */
    optional?: boolean;
    /**
     * The attendee's response status. Possible values are:
     ** "needsAction" - The attendee has not responded to the invitation.
     ** "declined" - The attendee has declined the invitation.
     ** "tentative" - The attendee has tentatively accepted the invitation.
     ** "accepted" - The attendee has accepted the invitation.
     */
    responseStatus: 'needsAction' | 'declined' | 'tentative' | 'accepted';
    /**
     * The attendee's response comment. Optional.
     */
    comment?: string;
    /**
     * Number of additional guests. Optional. The default is 0.
     */
    additionalGuests?: number;
}
//# sourceMappingURL=Attendee.d.ts.map