export interface ConferenceCreateRequest {
    /**
     * The client-generated unique ID for this request.
     * Clients should regenerate this ID for every new request. If an ID provided is the same as for the previous request, the request is ignored.
     */
    requestId: string;
    /**
     * The conference solution, such as Hangouts or Google Meet.
     */
    conferenceSolutionKey: {
        /**
         * The conference solution type.
         * If a client encounters an unfamiliar or empty type, it should still be able to display the entry points. However, it should disallow modifications.
         *
         * The possible values are:
         ** "eventHangout" for Hangouts for consumers (http://hangouts.google.com)
         ** "eventNamedHangout" for classic Hangouts for Google Workspace users (http://hangouts.google.com)
         ** "hangoutsMeet" for Google Meet (http://meet.google.com)
         ** "addOn" for 3P conference providers
         */
        type: 'eventHangout' | 'eventNamedHangout' | 'hangoutsMeet' | 'addOn';
    };
    /**
     * The status of the conference create request.
     */
    status: {
        /**
         * The current status of the conference create request. Read-only.
         *
         *The possible values are:
         ** "pending": the conference create request is still being processed.
         ** "success": the conference create request succeeded, the entry points are populated.
         ** "failure": the conference create request failed, there are no entry points.
         */
        statusCode: 'pending' | 'success' | 'failure';
    };
}
//# sourceMappingURL=ConferenceCreateRequest.d.ts.map