import { Event } from './Event';
export interface Events {
    /**
     * Type of the collection ("calendar#events").
     */
    kind: 'calendar#events';
    /**
     * ETag of the collection.
     */
    etag: string;
    /**
     * Title of the calendar. Read-only.
     */
    summary: string;
    /**
     * Description of the calendar. Read-only.
     */
    description?: string;
    /**
     * Last modification time of the calendar (as a RFC3339 timestamp). Read-only.
     */
    updated: string;
    /**
     * The time zone of the calendar. Read-only.
     */
    timeZone: string;
    /**
     * The user's access role for this calendar. Read-only. Possible values are:
     ** "none" - The user has no access.
     ** "freeBusyReader" - The user has read access to free/busy information.
     ** "reader" - The user has read access to the calendar. Private events will appear to users with reader access, but event details will be hidden.
     ** "writer" - The user has read and write access to the calendar. Private events will appear to users with writer access, and event details will be visible.
     ** "owner" - The user has ownership of the calendar. This role has all of the permissions of the writer role with the additional ability to see and manipulate ACLs.
     */
    accessRole: 'none' | 'freeBusyReader' | 'reader' | 'writer' | 'owner';
    /**
     * The default reminders on the calendar for the authenticated user. These reminders apply to all events on this calendar that do not explicitly override them (i.e. do not have reminders.useDefault set to True).
     */
    defaultReminders: {
        /**
         * The method used by this reminder. Possible values are:
         ** "email" - Reminders are sent via email.
         ** "popup" - Reminders are sent via a UI popup.
         *
         * Required when adding a reminder.
         */
        method: 'email' | 'popup';
        /**
         * Number of minutes before the start of the event when the reminder should trigger. Valid values are between 0 and 40320 (4 weeks in minutes).
         * Required when adding a reminder.
         */
        minutes: number;
    }[];
    /**
     * Token used to access the next page of this result. Omitted if no further results are available, in which case nextSyncToken is provided.
     */
    nextPageToken?: string;
    /**
     * Token used at a later point in time to retrieve only the entries that have changed since this result was returned. Omitted if further results are available, in which case nextPageToken is provided.
     */
    nextSyncToken?: string;
    /**
     * List of events on the calendar.
     */
    items: Event[];
}
//# sourceMappingURL=Events.d.ts.map