/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { Response, Headers, BaseApiCore, ErrorStrategyOptionType, PlatformImplementation } from '@managed-api/commons-core';
import { CommonError, AdditionalErrorTypes, ErrorStrategyHandlers, ErrorStrategyOption } from './errorStrategy';
import { ErrorStrategyBuilder } from './builders/errorStrategy';
import { GetCalendarsFromCalendarListRequest, GetCalendarsFromCalendarListResponseOK } from './types/calendarList';
import { CreateEventRequest, CreateEventResponseOK, DeleteEventRequest, DeleteEventResponseOK, GetEventRequest, GetEventResponseOK, GetEventsRequest, GetEventsResponseOK, UpdateEventRequest, UpdateEventResponseOK } from './types/event';
export interface GoogleCalendarApiCoreOptions extends ErrorStrategyOption {
}
declare type GetGlobalErrorStrategy = () => ErrorStrategyOptionType<CommonError, AdditionalErrorTypes, ErrorStrategyHandlers, ErrorStrategyBuilder> | undefined;
export declare abstract class GoogleCalendarApiCore extends BaseApiCore {
    private options?;
    All: AllGroup;
    CalendarList: CalendarListGroup;
    Event: EventGroup;
    constructor(options?: GoogleCalendarApiCoreOptions | undefined);
    setGlobalErrorStrategy(errorStrategy: ErrorStrategyOptionType<CommonError, AdditionalErrorTypes, ErrorStrategyHandlers, ErrorStrategyBuilder>): void;
    protected buildResponse(url: string, status: number, statusText: string, headers: Headers, body?: string | ArrayBuffer): Response<any>;
    private getGlobalErrorStrategy;
}
declare class AllGroup {
    private CalendarList;
    private Event;
    constructor(CalendarList: CalendarListGroup, Event: EventGroup);
    /**
     * Returns the calendars on the user's calendar list.
     * Alternative usage: CalendarList.getCalendarsFromCalendarList
     * Documentation: https://developers.google.com/calendar/v3/reference/calendarList/list
     * @param options Request options.
     */
    getCalendarsFromCalendarList<T = GetCalendarsFromCalendarListResponseOK>(options?: GetCalendarsFromCalendarListRequest): Promise<GetCalendarsFromCalendarListResponseOK | T>;
    /**
     * Deletes an event.
     * Alternative usage: Event.deleteEvent
     * Documentation: https://developers.google.com/calendar/v3/reference/events/delete
     * @param options Request options.
     */
    deleteEvent<T = DeleteEventResponseOK>(options: DeleteEventRequest): Promise<DeleteEventResponseOK | T>;
    /**
     * Returns an event.
     * Alternative usage: Event.getEvent
     * Documentation: https://developers.google.com/calendar/v3/reference/events/get
     * @param options Request options.
     */
    getEvent<T = GetEventResponseOK>(options: GetEventRequest): Promise<GetEventResponseOK | T>;
    /**
     * Creates an event.
     * Alternative usage: Event.createEvent
     * Documentation: https://developers.google.com/calendar/v3/reference/events/insert
     * @param options Request options.
     */
    createEvent<T = CreateEventResponseOK>(options: CreateEventRequest): Promise<CreateEventResponseOK | T>;
    /**
     * Returns events on the specified calendar.
     * Alternative usage: Event.getEvents
     * Documentation: https://developers.google.com/calendar/v3/reference/events/list
     * @param options Request options.
     */
    getEvents<T = GetEventsResponseOK>(options: GetEventsRequest): Promise<GetEventsResponseOK | T>;
    /**
     * Updates an event.
     * Alternative usage: Event.updateEvent
     * Documentation: https://developers.google.com/calendar/v3/reference/events/update
     * @param options Request options.
     */
    updateEvent<T = UpdateEventResponseOK>(options: UpdateEventRequest): Promise<UpdateEventResponseOK | T>;
}
declare class CalendarListGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Returns the calendars on the user's calendar list.
     * Documentation: https://developers.google.com/calendar/v3/reference/calendarList/list
     * @param options Request options.
     */
    getCalendarsFromCalendarList<T = GetCalendarsFromCalendarListResponseOK>(options?: GetCalendarsFromCalendarListRequest): Promise<GetCalendarsFromCalendarListResponseOK | T>;
}
declare class EventGroup {
    private implementation;
    private getGlobalErrorStrategy;
    constructor(implementation: PlatformImplementation, getGlobalErrorStrategy: GetGlobalErrorStrategy);
    /**
     * Deletes an event.
     * Documentation: https://developers.google.com/calendar/v3/reference/events/delete
     * @param options Request options.
     */
    deleteEvent<T = DeleteEventResponseOK>(options: DeleteEventRequest): Promise<DeleteEventResponseOK | T>;
    /**
     * Returns an event.
     * Documentation: https://developers.google.com/calendar/v3/reference/events/get
     * @param options Request options.
     */
    getEvent<T = GetEventResponseOK>(options: GetEventRequest): Promise<GetEventResponseOK | T>;
    /**
     * Creates an event.
     * Documentation: https://developers.google.com/calendar/v3/reference/events/insert
     * @param options Request options.
     */
    createEvent<T = CreateEventResponseOK>(options: CreateEventRequest): Promise<CreateEventResponseOK | T>;
    /**
     * Returns events on the specified calendar.
     * Documentation: https://developers.google.com/calendar/v3/reference/events/list
     * @param options Request options.
     */
    getEvents<T = GetEventsResponseOK>(options: GetEventsRequest): Promise<GetEventsResponseOK | T>;
    /**
     * Updates an event.
     * Documentation: https://developers.google.com/calendar/v3/reference/events/update
     * @param options Request options.
     */
    updateEvent<T = UpdateEventResponseOK>(options: UpdateEventRequest): Promise<UpdateEventResponseOK | T>;
}
export {};
//# sourceMappingURL=index.d.ts.map